@@ -1055,8 +1055,9 @@ class InterventionMessageAddView(app.BaseAddView):
         self.label = _("PLEASE REMEMBER: This information is part of the student's record.")
 
     def create(self, *args, **kw):
-        sender = IContact(self.request.principal._person)
-        return self._factory(sender, *args)
+        self._sender = IContact(self.request.principal._person)
+        self._recipients, body = args
+        return self._factory(body)
 
     def add(self, message):
         """Add message to the student's messages."""
@@ -1064,7 +1065,11 @@ class InterventionMessageAddView(app.BaseAddView):
         chooser = INameChooser(context)
         name = chooser.chooseName('', message)
         context[name] = message
-        email = sendmail.sendInterventionMessageEmail(message)
+        if self._sender:
+            message.sender.add(self._sender)
+        for recipient in self._recipients:
+            message.recipients.add(IContact(recipient))
+        sendmail.sendInterventionMessageEmail(message)
         return message
 
     def nextURL(self):
@@ -1171,9 +1176,10 @@ class InterventionStatusMessageAddView(app.BaseAddView):
     """View for adding a message."""
 
     def create(self, *args, **kw):
-        sender = IContact(self.request.principal._person)
-        kw['status_change'] = True
-        return self._factory(sender, *args, **kw)
+        self._sender = IContact(self.request.principal._person)
+        self._recipients, body = args
+        status_change = True
+        return self._factory(body, status_change=status_change)
 
     def add(self, message):
         """Add message to the student's messages."""
@@ -1181,7 +1187,11 @@ class InterventionStatusMessageAddView(app.BaseAddView):
         chooser = INameChooser(context)
         name = chooser.chooseName('', message)
         context[name] = message
-        email = sendmail.sendInterventionMessageEmail(message)
+        if self._sender:
+            message.sender.add(self._sender)
+        for recipient in self._recipients:
+            message.recipients.add(IContact(recipient))
+        sendmail.sendInterventionMessageEmail(message)
         return message
 
     def nextURL(self):
@@ -1343,9 +1353,12 @@ class InterventionGoalAddView(app.BaseAddView):
     """View for adding a goal."""
 
     def create(self, *args, **kw):
-        creator = IContact(self.request.principal._person)
-        kw['creator'] = creator
-        return self._factory(*args, **kw)
+        self._creator = IContact(self.request.principal._person)
+        goal, timeline, self._persons_responsible = args
+        return self._factory(goal, timeline,
+                             kw['presenting_concerns'], kw['strengths'], kw['indicators'],
+                             kw['intervention'], goal_met=kw['goal_met'],
+                             follow_up_notes=kw['follow_up_notes'])
 
     def add(self, goal):
         """Add goal to the student's goals."""
@@ -1353,7 +1366,10 @@ class InterventionGoalAddView(app.BaseAddView):
         chooser = INameChooser(context)
         name = chooser.chooseName('', goal)
         context[name] = goal
-        emails = sendmail.sendInterventionGoalAddEmail(goal)
+        goal.persons_responsible = self._persons_responsible
+        if self._creator is not None:
+            goal.creator.add(IContact(self._creator))
+        sendmail.sendInterventionGoalAddEmail(goal)
         return goal
 
     def nextURL(self):
