@@ -25,8 +25,10 @@ import unittest
 import doctest
 
 from zope.app.generations.utility import getRootFolder
+from zope.container.btree import BTreeContainer
 
 from schooltool.generations.tests import ContextStub
+from schooltool.generations.tests import setUp, tearDown
 from schooltool.intervention.generations.tests import provideAdapters
 from schooltool.intervention.generations.evolve2 import evolve
 from schooltool.intervention.intervention import InterventionMessage
@@ -39,21 +41,21 @@ def doctest_evolve2():
     First, we'll set up the app object:
 
         >>> provideAdapters()
-        >>> context = ContextStub()
+        >>> context = ContextStub(app)
         >>> app = getRootFolder(context)
 
     We'll set up our test with data that will be effected by running the
     evolve script:
 
-        >>> root = app[u'schooltool.interventions'] = {}
-        >>> year = root['2009'] = {}
-        >>> student = year['jdoe'] = {}
+        >>> root = app[u'schooltool.interventions'] = BTreeContainer()
+        >>> year = root['2009'] = BTreeContainer()
+        >>> student = year['jdoe'] = BTreeContainer()
 
-        >>> messages = student['messages'] = {}
+        >>> messages = student['messages'] = BTreeContainer()
         >>> message1 = messages['1'] = InterventionMessage('', '', '')
         >>> message1.created = datetime.now()
 
-        >>> goals = student['goals'] = {}
+        >>> goals = student['goals'] = BTreeContainer()
         >>> goal1 = goals['1'] = InterventionGoal('', '', '', '', '', '', '', 
         ...                                       '')
         >>> goal1.created = datetime.now()
@@ -76,7 +78,8 @@ def doctest_evolve2():
     What if the intervention container doesn't exist yet in the
     application:
 
-        >>> context = ContextStub()
+        >>> del app[u'schooltool.interventions']
+        >>> context = ContextStub(app)
         >>> app = getRootFolder(context)
         >>> evolve(context)
 
@@ -85,7 +88,8 @@ def doctest_evolve2():
 
 def test_suite():
     return unittest.TestSuite([
-        doctest.DocTestSuite(optionflags=doctest.ELLIPSIS
+        doctest.DocTestSuite(setUp=setUp, tearDown=tearDown,
+                             optionflags=doctest.ELLIPSIS
                                          | doctest.NORMALIZE_WHITESPACE
                                          | doctest.REPORT_NDIFF
                                          | doctest.REPORT_ONLY_FIRST_FAILURE),
@@ -93,4 +97,3 @@ def test_suite():
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
-
