@@ -25,11 +25,13 @@ import doctest
 
 from zope.app.testing import setup
 from zope.component.hooks import setSite
+from zope.container.btree import BTreeContainer
 from zope.interface import implements
 from zope.site.folder import Folder
 
 from schooltool.app.interfaces import ISchoolToolApplication
 from schooltool.generations.tests import ContextStub
+from schooltool.generations.tests import setUp, tearDown
 from schooltool.intervention.generations.evolve3 import evolve
 
 
@@ -42,50 +44,39 @@ def doctest_evolve3():
 
     First, we'll set up the app object:
 
-        >>> context = ContextStub()
-        >>> context.root_folder['app'] = app = AppStub()
-        >>> manager = setup.createSiteManager(app)
+        >>> context = ContextStub(app)
 
     We'll set up our test with data that will be effected by running the
     evolve script:
 
         >>> persons = app[u'persons'] = {'student1': ''}
-        >>> root = app[u'schooltool.interventions'] = {}
-        >>> year = root['2009'] = {}
-        >>> student1 = year['student1'] = {}
-        >>> student2 = year['student2'] = {}
+        >>> root = app[u'schooltool.interventions'] = BTreeContainer()
+        >>> year = root['2009'] = BTreeContainer()
+        >>> student1 = year['student1'] = BTreeContainer()
+        >>> student2 = year['student2'] = BTreeContainer()
 
     Finally, we'll run the evolve script, testing the effected values before and
     after:
 
         >>> sorted(year.keys())
-        ['student1', 'student2']
+        [u'student1', u'student2']
 
         >>> evolve(context)
 
         >>> sorted(year.keys())
-        ['student1']
+        [u'student1']
 
     What if the intervention container doesn't exist yet in the
     application:
 
-        >>> context = ContextStub()
-        >>> context.root_folder['app'] = app = AppStub()
+        >>> del app[u'schooltool.interventions']
+        >>> context = ContextStub(app)
         >>> manager = setup.createSiteManager(app)
         >>> evolve(context)
 
     """
 
 
-def setUp(test):
-    setup.placefulSetUp()
-    setSite()
-
-def tearDown(test):
-    setup.placefulTearDown()
-    setSite()
-
-
 def test_suite():
     return unittest.TestSuite([
         doctest.DocTestSuite(setUp=setUp, tearDown=tearDown,
@@ -97,4 +88,3 @@ def test_suite():
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
-
