@@ -25,11 +25,14 @@ import doctest
 
 from zope.app.testing import setup
 from zope.component.hooks import setSite
+from zope.container.btree import BTreeContainer
+from zope.container.contained import Contained
 from zope.interface import implements
 from zope.site.folder import Folder
 
 from schooltool.app.interfaces import ISchoolToolApplication
 from schooltool.generations.tests import ContextStub
+from schooltool.generations.tests import setUp, tearDown
 from schooltool.intervention.generations.evolve4 import evolve
 from schooltool.intervention.interfaces import IInterventionGoal
 
@@ -38,7 +41,7 @@ class AppStub(Folder):
     implements(ISchoolToolApplication)
 
 
-class GoalStub(object):
+class GoalStub(Contained):
     implements(IInterventionGoal)
     _persons_responsible = []
     __dict__ = {'persons_responsible': ['jdoe']}
@@ -50,19 +53,17 @@ def doctest_evolve4():
 
     First, we'll set up the app object:
 
-        >>> context = ContextStub()
-        >>> context.root_folder['app'] = app = AppStub()
-        >>> app[u'schooltool.interventions'] = {}
-        >>> manager = setup.createSiteManager(app)
+        >>> context = ContextStub(app)
+        >>> app[u'schooltool.interventions'] = BTreeContainer()
 
     We'll set up our test with data that will be effected by running the
     evolve script:
 
         >>> root = app[u'schooltool.interventions']
-        >>> year = root['2009'] = {}
-        >>> student = year['jdoe'] = {}
+        >>> year = root['2009'] = BTreeContainer()
+        >>> student = year['jdoe'] = BTreeContainer()
 
-        >>> goals = student['goals'] = {}
+        >>> goals = student['goals'] = BTreeContainer()
         >>> goal1 = goals['1'] = GoalStub()
 
     Finally, we'll run the evolve script, testing the effected values before and
@@ -87,23 +88,13 @@ def doctest_evolve4():
     What if the intervention container doesn't exist yet in the
     application:
 
-        >>> context = ContextStub()
-        >>> context.root_folder['app'] = app = AppStub()
-        >>> manager = setup.createSiteManager(app)
+        >>> del app[u'schooltool.interventions']
+        >>> context = ContextStub(app)
         >>> evolve(context)
 
     """
 
 
-def setUp(test):
-    setup.placefulSetUp()
-    setSite()
-
-def tearDown(test):
-    setup.placefulTearDown()
-    setSite()
-
-
 def test_suite():
     return unittest.TestSuite([
         doctest.DocTestSuite(setUp=setUp, tearDown=tearDown,
