@@ -25,11 +25,13 @@ import doctest
 
 from zope.app.testing import setup
 from zope.component.hooks import setSite
+from zope.container.btree import BTreeContainer
 from zope.interface import implements
 from zope.site.folder import Folder
 
 from schooltool.app.interfaces import ISchoolToolApplication
 from schooltool.generations.tests import ContextStub
+from schooltool.generations.tests import setUp, tearDown
 from schooltool.intervention.generations.evolve6 import evolve
 
 
@@ -42,49 +44,38 @@ def doctest_evolve6():
 
     First, we'll set up the app object:
 
-        >>> context = ContextStub()
-        >>> context.root_folder['app'] = app = AppStub()
-        >>> manager = setup.createSiteManager(app)
+        >>> context = ContextStub(app)
 
     We'll set up our test with data that will be effected by running the
     evolve script:
 
-        >>> app[u'schooltool.schoolyear'] = {'2009': ''}
-        >>> root = app[u'schooltool.interventions'] = {}
-        >>> root['2008'] = {}
-        >>> root['2009'] = {}
+        >>> app[u'schooltool.schoolyear'] = BTreeContainer()
+        >>> app[u'schooltool.schoolyear'][u'2009'] = BTreeContainer()
+        >>> root = app[u'schooltool.interventions'] = BTreeContainer()
+        >>> root['2008'] = BTreeContainer()
+        >>> root['2009'] = BTreeContainer()
 
     Finally, we'll run the evolve script, testing the effected values before and
     after:
 
         >>> sorted(root.keys())
-        ['2008', '2009']
+        [u'2008', u'2009']
 
         >>> evolve(context)
 
         >>> sorted(root.keys())
-        ['2009']
+        [u'2009']
 
     What if the intervention container doesn't exist yet in the
     application:
 
-        >>> context = ContextStub()
-        >>> context.root_folder['app'] = app = AppStub()
-        >>> manager = setup.createSiteManager(app)
+        >>> del app[u'schooltool.interventions']
+        >>> context = ContextStub(app)
         >>> evolve(context)
 
     """
 
 
-def setUp(test):
-    setup.placefulSetUp()
-    setSite()
-
-def tearDown(test):
-    setup.placefulTearDown()
-    setSite()
-
-
 def test_suite():
     return unittest.TestSuite([
         doctest.DocTestSuite(setUp=setUp, tearDown=tearDown,
@@ -96,4 +87,3 @@ def test_suite():
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
-
