@@ -24,10 +24,13 @@ from datetime import datetime
 import unittest
 import doctest
 
+from persistent import Persistent
 from zope.annotation.interfaces import IAttributeAnnotatable
 from zope.app.generations.utility import getRootFolder
 from zope.app.testing import setup
 from zope.component.hooks import getSite, setSite
+from zope.container.btree import BTreeContainer
+from zope.container.contained import Contained
 from zope.interface import implements
 from zope.site.folder import Folder
 
@@ -36,6 +39,7 @@ from schooltool.basicperson.person import BasicPerson
 from schooltool.contact.contact import Contact
 from schooltool.contact.interfaces import IContactable
 from schooltool.generations.tests import ContextStub
+from schooltool.generations.tests import setUp, tearDown
 from schooltool.person.interfaces import IPerson
 
 from schooltool.intervention.generations.tests import provideAdapters
@@ -44,11 +48,7 @@ from schooltool.intervention.intervention import InterventionMessage
 from schooltool.intervention.intervention import InterventionGoal
 
 
-class AppStub(Folder):
-    implements(ISchoolToolApplication)
-
-
-class ParentStub(object):
+class ParentStub(Persistent, Contained):
     implements(IAttributeAnnotatable)
     first_name = 'Parent'
     last_name = 'Name'
@@ -63,24 +63,24 @@ def doctest_evolve7():
 
     We need an app.
 
-        >>> context = ContextStub()
-        >>> context.root_folder['app'] = app = AppStub()
-        >>> manager = setup.createSiteManager(app)
+        >>> provideAdapters()
+        >>> context = ContextStub(app)
 
     We need a teacher, a student and a parent.
 
-        >>> persons = app[u'persons'] = {}
+        >>> persons = app[u'persons'] = BTreeContainer()
         >>> jteacher = persons['jteacher'] = BasicPerson('jteacher', 'John', 'Teacher')
         >>> jstudent = persons['jstudent'] = BasicPerson('jstudent', 'Jane', 'Student')
-        >>> IContactable(jstudent).contacts.add(ParentStub())
+        >>> parent = persons['parent'] = ParentStub()
+        >>> IContactable(jstudent).contacts.add(parent)
 
     Finally we need an intervention root, schoolyear and student.
 
-        >>> root = app[u'schooltool.interventions'] = {}
-        >>> year = root['thisyear'] = {}
-        >>> student = year['jstudent'] = {}
-        >>> messages = student['messages'] = {}
-        >>> goals = student['goals'] = {}
+        >>> root = app[u'schooltool.interventions'] = BTreeContainer()
+        >>> year = root['thisyear'] = BTreeContainer()
+        >>> student = year['jstudent'] = BTreeContainer()
+        >>> messages = student['messages'] = BTreeContainer()
+        >>> goals = student['goals'] = BTreeContainer()
 
     Our first test will be with a message and goal with all good ids.
 
@@ -181,24 +181,13 @@ def doctest_evolve7():
     What if the intervention container doesn't exist yet in the
     application:
 
-        >>> context = ContextStub()
-        >>> context.root_folder['app'] = app = AppStub()
-        >>> manager = setup.createSiteManager(app)
+        >>> del app[u'schooltool.interventions']
+        >>> context = ContextStub(app)
         >>> evolve(context)
 
     """
 
 
-def setUp(test):
-    setup.placefulSetUp()
-    provideAdapters()
-    setSite()
-
-def tearDown(test):
-    setup.placefulTearDown()
-    setSite()
-
-
 def test_suite():
     return unittest.TestSuite([
         doctest.DocTestSuite(setUp=setUp, tearDown=tearDown,
@@ -211,4 +200,3 @@ def test_suite():
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
-
