@@ -35,6 +35,7 @@ from zope.catalog.interfaces import ICatalog
 
 from schooltool.app.interfaces import ISchoolToolApplication
 from schooltool.generations.tests import ContextStub
+from schooltool.generations.tests import setUp, tearDown
 from schooltool.intervention.generations.evolve8 import evolve, CATALOG_KEY
 
 
@@ -54,22 +55,15 @@ class UtilityStub(Folder):
         return '<%s (%s)>' % (self.__class__.__name__, self.name)
 
 
-class AppStub(Folder):
-    implements(ISchoolToolApplication)
-
-
 def doctest_evolve8():
     """Test evolution to generation 8.
 
     First, let's build ST app with local catalog utility.
 
-        >>> context = ContextStub()
-        >>> context.root_folder['app'] = app = AppStub()
-        >>> app.setSiteManager(LocalSiteManager(app))
+        >>> context = ContextStub(app)
 
         >>> registerLocalUtility(app, UtilityStub(CATALOG_KEY), CATALOG_KEY)
 
-        >>> setSite(app)
         >>> print queryUtility(ICatalog, name=CATALOG_KEY, default=None)
         <UtilityStub (schooltool.intervention)>
 
@@ -95,15 +89,6 @@ def doctest_evolve8():
     """
 
 
-def setUp(test):
-    setup.placefulSetUp()
-    setup.setUpTraversal()
-
-
-def tearDown(test):
-    setup.placefulTearDown()
-
-
 def test_suite():
     optionflags = (doctest.ELLIPSIS |
                    doctest.NORMALIZE_WHITESPACE |
