@@ -86,7 +86,7 @@ class IInterventionSchoolYear(IContainer):
 class IInterventionStudent(IContainer):
     """Container of the student's intervention containers."""
 
-    contains('zope.app.IContainer')
+    contains(IContainer)
     containers(IInterventionSchoolYear)
 
 
