@@ -26,15 +26,19 @@ import doctest
 from zope.annotation.interfaces import IAnnotatable
 from zope.app.testing import setup
 from zope.component import provideAdapter, Interface
+from zope.container.btree import BTreeContainer
 
 from schooltool.app.app import getSchoolToolApplication
 from schooltool.basicperson.interfaces import IBasicPerson
 from schooltool.contact.basicperson import getBoundContact
 from schooltool.contact.basicperson import getPersonOfBoundContact
 from schooltool.contact.contact import Contactable
+from schooltool.generations.tests import setUp as packageSetUp
+from schooltool.generations.tests import tearDown
 from schooltool.relationship.interfaces import IRelationshipLinks
 from schooltool.relationship.annotatable import getRelationshipLinks
 from schooltool.schoolyear.schoolyear import getSchoolYearContainer
+from schooltool.schoolyear.schoolyear import SchoolYearInit
 from schooltool.term.interfaces import ITermContainer
 from schooltool.term.term import getTermContainer
 from schooltool.term.term import getSchoolYearForTerm
@@ -45,7 +49,7 @@ optionflags = (doctest.ELLIPSIS|doctest.REPORT_ONLY_FIRST_FAILURE|
                doctest.NORMALIZE_WHITESPACE)
 
 def setUp(test):
-    setup.placefulSetUp()
+    packageSetUp(test)
     provideAdapter(getSchoolToolApplication)
     provideAdapter(getTermContainer, [Interface], ITermContainer)
     provideAdapter(getSchoolYearForTerm)
@@ -68,8 +72,13 @@ def setUp(test):
     provideAdapter(adapters.getInterventionGoalsStudent)
     provideAdapter(adapters.getInterventionGoalStudent)
 
-def tearDown(test):
-    setup.placefulTearDown()
+    app = test.globs['app']
+    app['persons'] = BTreeContainer()
+    app['messages'] = BTreeContainer()
+    app['goals'] = BTreeContainer()
+    SchoolYearInit(app)()
+    adapters.InterventionInit(app)()
+
 
 def test_suite():
     return unittest.TestSuite([
